@@ -6,7 +6,7 @@
 use strict;
 use warnings;
 
-use XML::RSS;
+use XML::RSS ();
 
 my $rss = XML::RSS->new;
 $rss->parsefile(shift);
